#!/bin/sh
# PostUpdateScript for Customization Gen2 firmware version 1.18.1ff
# baduro1, 24.04.2020

# definitions:
UPDATE_LOGFILE=/var/log/update.log

PARAM_CUSTOMIZING_NAME=SMS

HMI_CUSTOMIZING_FILE=SMS.tar
HMI_CUSTOMIZING_DIR=/CustomPrgm/WebServices/client/app

PARAM_VALUES_FILES='aps_eventvis_params_values.xml aps_iot_params_values.xml aps_psp_params_values.xml aps_pubsub_params_values.xml aps_restpush_params_values.xml datafilerec_params_values.xml datafilerec_wirelesstracking_params_values.xml datafilerec_zonemonitoring_params_values.xml network_services_params_values.xml nw_eth0_dhcp_params_values.xml nw_eth0_static_dns_params_values.xml nw_eth0_static_ipv4_params_values.xml rest_api_params_values.xml soap_pushservice_params_values.xml'

PARAM_FACTORY_DIR=/var/Counter/FactorySettings/configs/0/
PARAM_ACTIVE_DIR=/var/Counter/configs/0/

HMI_PASSWORDS_NEW=hmi_passwd_values.xml
HMI_PASSWORDS_STD=hmi_passwd_values_standard.xml
HMI_PASSWORDS_STD_OLD=hmi_passwd_values_standard_old.xml
HMI_PASSWORDS_CUR=/var/Counter/configs/0/hmi_passwd_values.xml
SYS_PASSWORD_SHADOW_FILE=shadow
SYS_PASSWORD_TEMP_DIR=/CustomPrgm/TempSysPassords/
LED_STATUS_PARAMS=aps_eventvis_params_values.xml

META_FILE1=countingpolygons_meta.xml
META_TEMP_DIR=/CustomPrgm/TempParamMetaFiles/

# SCRIPT_FACTORY_RESET_FILE=S61FactoryReset
SCRIPT_LED_CUSTOMIZING_FILE=S99XGreenStatusLED
SCRIPT_PASSWORD_CUSTOMIZING_FILE=S35XSysPasswords
SCRIPT_META_CUSTOMIZING_FILE=S35XMetaFiles
SCRIPTS_CUSTOMIZING_DIR=/CustomPrgm/etc/init.d/rc1.d/


### start of customization
LOGSTR="$(date): Performing ${PARAM_CUSTOMIZING_NAME} customization..."
echo ${LOGSTR} >>${UPDATE_LOGFILE}
logger ${LOGSTR}

# exit immediately if any command exits with a non-zero status
set -e

# copy all param files
for i in ${PARAM_VALUES_FILES}; do
	cp -f ${i} ${PARAM_FACTORY_DIR}
done

# exchange HMI passwords - and current HMI passwords, if HAGL standard (new 1.18 or older)
cp -f ${HMI_PASSWORDS_NEW}  ${PARAM_FACTORY_DIR}
if diff -q ${HMI_PASSWORDS_CUR} ${HMI_PASSWORDS_STD}; then
	cp -f ${HMI_PASSWORDS_NEW} ${HMI_PASSWORDS_CUR}
	LOGSTR="$(date): set new HMI passwords, because of probably used current defaults."
	echo ${LOGSTR} >>${UPDATE_LOGFILE}
	logger ${LOGSTR}
else
	if diff -q ${HMI_PASSWORDS_CUR} ${HMI_PASSWORDS_STD_OLD}; then
		cp -f ${HMI_PASSWORDS_NEW} ${HMI_PASSWORDS_CUR}
		LOGSTR="$(date): set new HMI passwords, because of probably used old defaults."
		echo ${LOGSTR} >>${UPDATE_LOGFILE}
		logger ${LOGSTR}
	else
		LOGSTR="$(date): keep previous changed HMI passwords."
		echo ${LOGSTR} >>${UPDATE_LOGFILE}
		logger ${LOGSTR}
	fi
fi

# customize HMI
mount -o remount,rw /CustomPrgm
mkdir -p ${HMI_CUSTOMIZING_DIR}
rm -rf ${HMI_CUSTOMIZING_DIR}/*
tar -xvf ${HMI_CUSTOMIZING_FILE} -C ${HMI_CUSTOMIZING_DIR}
LOGSTR="$(date): HMI customization installed."
echo ${LOGSTR} >>${UPDATE_LOGFILE}
logger ${LOGSTR}

# delete old customizing startup with LED, if exists
if test -f ${SCRIPTS_CUSTOMIZING_DIR}${SCRIPT_LED_CUSTOMIZING_FILE}; then
    # mount -o remount,rw /CustomPrgm
	# copy and overwrite LED params aps_eventvis_params_values.xml if old script S99XGreenStatusLED existing
	cp -f ${PARAM_FACTORY_DIR}${LED_STATUS_PARAMS} ${PARAM_ACTIVE_DIR}
	rm -f ${SCRIPTS_CUSTOMIZING_DIR}${SCRIPT_LED_CUSTOMIZING_FILE}
    LOGSTR="$(date): old, continuous green LED customization script removed."
    echo ${LOGSTR} >>${UPDATE_LOGFILE}
    logger ${LOGSTR}
fi

# prepare the exchange param meta files
# mount -o remount,rw /CustomPrgm
mkdir -p ${META_TEMP_DIR}
cp -f ${META_FILE1} ${META_TEMP_DIR}
mkdir -p ${SCRIPTS_CUSTOMIZING_DIR}
cp -f ${SCRIPT_META_CUSTOMIZING_FILE} ${SCRIPTS_CUSTOMIZING_DIR}

LOGSTR="$(date): new parameter META files prepared - update after first reboot."
echo ${LOGSTR} >>${UPDATE_LOGFILE}
logger ${LOGSTR}


# prepare the exchange of current system passwords after reboot
# mount -o remount,rw /CustomPrgm
mkdir -p ${SYS_PASSWORD_TEMP_DIR}
cp -f ${SYS_PASSWORD_SHADOW_FILE} ${SYS_PASSWORD_TEMP_DIR}
# mkdir -p ${SCRIPTS_CUSTOMIZING_DIR}
cp -f ${SCRIPT_PASSWORD_CUSTOMIZING_FILE} ${SCRIPTS_CUSTOMIZING_DIR}
LOGSTR="$(date): new system passwords prepared - update after first reboot."
echo ${LOGSTR} >>${UPDATE_LOGFILE}
logger ${LOGSTR}


LOGSTR="$(date): Successfully installed ${PARAM_CUSTOMIZING_NAME} customization..."
echo ${LOGSTR} >>${UPDATE_LOGFILE}
logger ${LOGSTR}

# the end
