#!/bin/sh

# Include the calibration definition and helper functions
source /etc/Counter/CalibDefs.sh

# Include helper stuff for reading xml files
source  /etc/init.d/rc1.d/_HelperFunctions/XmlParameter

# Return with error, if an undefined variable is used
set -u

# Get FPGA-type
FPGA_TYPE=`GetParamValue aps_ip_fpga_params FpgaType`

if [ x"${FPGA_TYPE}" = x"2" ] ; then
  # Zoom
  CALDEF_DIR_TMPTYPEREL="zoom"
else
  # Binning VGA/QVGA
  CALDEF_DIR_TMPTYPEREL="binning"
fi

# Absolute path to the feature specific working calibration (e.g. .../cal/binning)
CALDEF_DIR_TMPTYPE=${CALDEF_DIR_TMP}${CALDEF_DIR_TMPTYPEREL}

# And to the copy of ini-file, used as tag to determine the correct association between current ini and working ini
CALDEF_FILE_TMPTYPE_INTERN_INI_SRC="$CALDEF_DIR_TMPTYPE/intern_640x480.ini.src"

# Create dir
mkdir -p $CALDEF_DIR_TMP

# Create links dependent on the FPGA-type
rm -f $CALDEF_FILE_TMP_INTERN_INI
ln -sf $CALDEF_DIR_TMPTYPEREL/intern_640x480.ini $CALDEF_FILE_TMP_INTERN_INI
rm -f $CALDEF_FILE_TMP_RECTIFIED_XML
ln -sf $CALDEF_DIR_TMPTYPEREL/intern_relative_calib_values.xml $CALDEF_FILE_TMP_RECTIFIED_XML
rm -f $CALDEF_FILE_TMP_LUT
ln -sf $CALDEF_DIR_TMPTYPEREL/vgalut $CALDEF_FILE_TMP_LUT
rm -f $CALDEF_FILE_TMP_MD5
ln -sf $CALDEF_DIR_TMPTYPEREL/md5sums.txt $CALDEF_FILE_TMP_MD5


# Flag, defining whether working files have to created or not
CREATE_CAL_CUR=n

# If the current ini file differs to the copy stored in /var/tmp we need to create new working files
diff -q $CALDEF_FILE_CUR_INTERN_INI $CALDEF_FILE_TMPTYPE_INTERN_INI_SRC 2> /dev/null
RET=$?
if [ $RET -ne 0 ] ; then
    # Files differ
    CREATE_CAL_CUR=y
    echo                 "$0: Calibration ini files differ"
    logger -p user.error "$0: Calibration ini files differ"
fi


# Check MD5 for working calibration
md5sum -s -c $CALDEF_FILE_TMP_MD5
RET=$?
if [ $RET -ne 0 ] ; then
    # Check failed
    CREATE_CAL_CUR=y
    echo                 "$0: MD5 check failed"
    logger -p user.error "$0: MD5 check failed"
fi


# Create corking calibration data, if needed
if [ $CREATE_CAL_CUR = "y" ] ; then
    # Create dir
    mkdir -p $CALDEF_DIR_TMPTYPE

    # Create working calibration data dependent on the FPGA-type
    if [ x"${FPGA_TYPE}" = x"2" ] ; then
      # Zoom
      /sbin/CalibFromIni -z -f $CALDEF_FOCAL_FACTOR_ZOOM -s $CALDEF_FILE_CUR_INTERN_INI \
        -i $CALDEF_FILE_TMP_INTERN_INI -x $CALDEF_FILE_TMP_RECTIFIED_XML -l $CALDEF_FILE_TMP_LUT
    else
      # VGA/QVGA
      /sbin/CalibFromIni -f $CALDEF_FOCAL_FACTOR_08 -s $CALDEF_FILE_CUR_INTERN_INI \
        -i $CALDEF_FILE_TMP_INTERN_INI -x $CALDEF_FILE_TMP_RECTIFIED_XML -l $CALDEF_FILE_TMP_LUT
    fi
    
    # Copy the ini-file, used as tag to determine the correct association between the current ini and the working ini
    cp $CALDEF_FILE_CUR_INTERN_INI $CALDEF_FILE_TMPTYPE_INTERN_INI_SRC
    
    # Create checksums
    md5sum $CALDEF_FILE_TMP_INTERN_INI $CALDEF_FILE_TMP_RECTIFIED_XML $CALDEF_FILE_TMP_LUT > $CALDEF_FILE_TMP_MD5

    # Output
    echo                  "$0: Created working calibration data"
    logger -p user.notice "$0: Created working calibration data"
fi

exit 0

