#!/bin/sh

. snapshot_creation_fn.sh

############################################################
#
# Script creates a tar file with video snapshots
#    - left original
#    - right rectified
#    - disparity map
#
# tar-file: /tmp/Snapshots.tar.gz
#
############################################################

# helper functions
fnEchoErr() { 
    echo "$@" 1>&2;
}

fnCleanup() {
    rm -rf ${TAR_TARGET_DIR} >/dev/null 2>&1
}

# tar file
TAR_TARGET_DIR="/tmp/tmp_snapshots"
TAR_FILE="/tmp/Snapshots.tar.gz"

# privacy mode flag
FILE_PRIVACY_MODE=/tmp/privacy-mode

# Initial Clean-up
# Check if tar file exist, if exist delete it.
rm -f ${TAR_FILE} >/dev/null 2>&1
fnCleanup

# get video snapshots
if [ -f ${FILE_PRIVACY_MODE} ]; then
    logger -p user.notice "$0: Video snapshots supressed by privacy flag"
    fnCleanup
    exit 4
else
    fnRecordVideoSnapshots ${TAR_TARGET_DIR}
    RES_TMP=$?
    if [ ${RES_TMP} -ne 0 ] ; then
        logger -p user.error "$0: failed to obtain video snapshots"
        fnEchoErr "failed to obtain video snapshots"
        fnCleanup
        exit 3
    fi
fi

# tar (compressed with gzip) copied data for export
tar -c -z -f ${TAR_FILE} -C ${TAR_TARGET_DIR} . >/dev/null 2>&1
RES_TAR=$?
if [ ${RES_TAR} -ne 0 ] ; then
    logger -p user.error "$0: tar returned an error: ${RES_TAR}"
    fnEchoErr "tar command returned an error: ${RES_TAR}"
    rm -f ${TAR_FILE} >/dev/null 2>&1
    fnCleanup
    exit 2
fi

# exit with success, tar file shall exist in ${TAR_FILE}
logger -p user.info "$0: Snapshots creation successfully performed, file ready: '${TAR_FILE}'"
fnCleanup
exit 0
