#!/bin/sh

# set to 1 if logs should be printed to stderr instead of just to message log
DEBUG=0

# logs to std err
logToConsole () { 
    echo -e "$0, $@" 1>&2;
}

# logs to /var/log/messages and to stderr if DEBUG is set to 1
log () {
    logger -p user.error "$0: $1"
    # if DEBUG is 1 -> also log to console
    if [ ${DEBUG} -eq 1 ]
    then
        logToConsole $1
    fi
}

usage ()
{
    log "Usage: "
    log "           $0 <image_path>"
    log "arguments: "
    log "           image_path:  full path defining where to store stitched image snapshot (in png format)"
}

#################################################################################################
# script starts here
#################################################################################################

if [ $# -ne 1 ]
then
    log "Error, wrong number of parameters in call to script!"
    usage
    exit 1
fi 

# get argument
IMG_PATH=$1

# determine image size using "/sbin/Stitcher -i"
IMG_WIDTH=`/sbin/Stitcher -i | cut -d" " -f3` 
IMG_HEIGHT=`/sbin/Stitcher -i | cut -d" " -f5`
IMG_BPP=`/sbin/Stitcher -i | cut -d" " -f7`
IMG_SIZE=`expr ${IMG_WIDTH} \* ${IMG_HEIGHT} \* ${IMG_BPP}`

# acquire stitched image and transform to png
# env vars for GSTreamer
export GST_PLUGIN_SYSTEM_PATH_1_0=/lib/gstreamer-1.0
export GST_PLUGIN_PATH_1_0=/lib/gstreamer-1.0

# use Stitcher output as input for gst
/sbin/Stitcher | \
   gst-launch-1.0 -v fdsrc blocksize=${IMG_SIZE}  \
   ! video/x-raw, format=RGB16, interlaced=false, width=${IMG_WIDTH}, height=${IMG_HEIGHT}, framerate=1/1 \
   ! videocrop top=1 left=0 right=0 bottom=1 \
   ! videoconvert \
   ! pngenc \
   ! filesink location=${IMG_PATH}

RES=$?

if [ $RES -ne 0 ]
then
    log "$0: failed to obtain stitched image." 
else
    log "$0: stitched image of size: ${IMG_SIZE} (${IMG_WIDTH} x ${IMG_HEIGHT} x ${IMG_BPP}) saved as: ${IMG_PATH}." 
fi
