#!/bin/sh

source /etc/init.d/rc1.d/_HelperFunctions/XmlParameter

# set to 1 if logs should be printed to stderr instead of just to message log
DEBUG=0

# logs to std err
logToConsole () { 
    echo -e "$0, $@" 1>&2;
}

# logs to /var/log/messages and to stderr if DEBUG is set to 1
log () {
    logger -p user.error "$0: $1"
    # if DEBUG is 1 -> also log to console
    if [ ${DEBUG} -eq 1 ]
    then
        logToConsole $1
    fi
}

usage ()
{
    log "Usage: "
    log "           $0 <dirname>"
    log "arguments: "
    log "           dir:    folder in which old video files have to be deleted"
}


#################################################################################################
# script starts here
#################################################################################################

if [ $# -lt 1 ]
then
    log "Error, wrong number of parameters in call to script!"
    usage
    exit 1
fi 

# get folder that shall be cleaned from arguments
VIDEO_DIR=$1
if [ ! -d ${VIDEO_DIR} ] ; then
    # directory does not exist:
    exit 2
fi

# get time from params after which video shall be deleted
STORAGE_DURA_HOURS=`GetParamValue aps_videorecording_params StorageDuration_Hours`
if [ "${STORAGE_DURA_HOURS}" -ne "${STORAGE_DURA_HOURS}" ] 2>/dev/null ; then
    # not an integer:
    exit 3
fi

# shall files be deleted?
if [ 0 -eq ${STORAGE_DURA_HOURS} ] ; then
    # Files shall not be removed at all:
    exit 0
fi

#log "${0}: deleting videos that are older than ${STORAGE_DURA_HOURS} hours."

# convert hours to minutes, because find -mmin needs minutes:
STORAGE_DURA_MINUTES=$((60 * ${STORAGE_DURA_HOURS}))

BE_NICE="nice ionice -c 3"

# find old files and remove them
${BE_NICE} find ${VIDEO_DIR} -maxdepth 1 -mindepth 1 -mmin +${STORAGE_DURA_MINUTES} -exec rm -rf {} \; 2>/dev/null
