#!/usr/bin/env /usr/local/bin/python3
# -*- coding: utf-8 -*-
##########################################################################
#
#    name:           ScheduleVideoRecording.py
#    author:         Julia Ick (ick)
#    description:    Schedules new video recording 
#                    using StartScheduledRecording.py
#
##########################################################################

import os
import sys
import argparse
import syslog
from crontab import CronTab



#############################################################################
# main
#############################################################################
def main (argv):
    
    parser = argparse.ArgumentParser(description='Schedules new video recording using StartScheduledRecording.py.')

    # configure parser
    parser.add_argument('-duration', metavar='duration', type=int, help='desired video duration in seconds')
    parser.add_argument('-month' , metavar='month', type=int,help='start date month')
    parser.add_argument('-day' , metavar='day', type=int,help='start date day')
    parser.add_argument('-dow' , metavar='dow', type=int,help='start date day of week')
    parser.add_argument('-hour' , metavar='hour', type=int,help='start date hour')
    parser.add_argument('-min' , metavar='min', type=int,help='start date min')
    parser.add_argument('-repeat' , metavar='repeat', choices=['monthly', 'weekly', 'daily', 'none'], default='none',help='repetition interval')

    # parse
    args = parser.parse_args()
    
    # debug
    #syslog.syslog(syslog.LOG_ERR, 'script called with arguments: ')
    #syslog.syslog(syslog.LOG_ERR, '\tduration: ' + str(args.duration))
    #syslog.syslog(syslog.LOG_ERR, '\tmonth: ' + str(args.month))
    #syslog.syslog(syslog.LOG_ERR, '\tday: ' + str(args.day))
    #syslog.syslog(syslog.LOG_ERR, '\tdow: ' + str(args.dow))
    #syslog.syslog(syslog.LOG_ERR, '\thour: ' + str(args.hour))
    #syslog.syslog(syslog.LOG_ERR, '\tmin: ' + str(args.min))
    #syslog.syslog(syslog.LOG_ERR, '\trepeat: ' + str(args.repeat))
    
    featureComment = 'CUSTOMER_VIDEO_TIMER'
    featureCommand = '/usr/local/bin/python3 /sbin/StartScheduledVideoRecording.py '
    featureCommand = featureCommand + str(args.duration)
    if args.repeat != 'none':
        featureCommand = featureCommand + " -repeatMode"
    
    myCronTab = CronTab(user='root')
    jobs = myCronTab.find_comment(featureComment)
    for job in jobs:
        myCronTab.remove(job)
    
    job  = myCronTab.new(command=featureCommand, comment=featureComment)
    # set daily
    job.minute.on(args.min)
    job.hour.on(args.hour)
    if args.repeat == 'none':
        job.month.on(args.month)
        job.day.on(args.day)
    elif args.repeat == 'monthly':
        job.day.on(args.day)
    elif args.repeat == 'weekly':
        job.dow.on(args.dow)
        
    myCronTab.write()
    


if __name__ == "__main__":
   main(sys.argv)

