#!/bin/sh

if [ 3 -ne $# ] ; then
    echo "3 parameters needed: DestFilename duration[min] URI"
    exit 1
fi

DEST_FILE=$1
MAX_DURATION_SEC=$2
URI=$3

if [ -f /etc/profile ] ; then
    source /etc/profile
fi

TIME_CMD=/usr/bin/time
DURATION_FILE="/tmp/FU_wgetdura.txt"
PERSISTENT_URI_RETRIEVAL_FILE="/var/Counter/config/update_uri.cfg"
FIRST_TIME_FAILED_FLAG=1
STOP_RETRIEVAL_FLAG=0
SLEEP_TIME_SEC=600  # 10 * 60 s = 10 min
PASSED_TIME_SEC=0
RET=1

#----------------------------------------------------------------------------------------------------
CreatePersistentFile()
{
    HOUR_METER=`cat /var/log/hour-meter.log |sed -e 's/[^0-9]//g'`
    if [ "x" == "x$HOUR_METER" ] ; then
        HOUR_METER=0
    fi

    # XXX Caution: The busybox desk calculator dc behaves differently than the usual versions:
    # Normally dc calculates in int. For rational numbers a command like 4k is needed. Busybox dc
    # will terminate on k command and calculate with broken numbers by default:
    MAX_DURATION_H=`echo "$MAX_DURATION_SEC 60 / 60 / 0.5 + p" |dc |sed -e's/\..*//'`

    echo "uri=$URI"                      > $PERSISTENT_URI_RETRIEVAL_FILE
    echo "hour-of-reception=$HOUR_METER" >>$PERSISTENT_URI_RETRIEVAL_FILE
    echo "duration-hours=$MAX_DURATION_H"  >>$PERSISTENT_URI_RETRIEVAL_FILE
}
#----------------------------------------------------------------------------------------------------

# XXX FAKE section for quicken debugging:
# Clearing of http_proxy is necessary for work on thalia (at least when I try it)
#export http_proxy=
#SLEEP_TIME_SEC=5
#MAX_DURATION_SEC=10
# EO FAKE section

if [ $MAX_DURATION_SEC -lt 0 ] ; then
    MAX_DURATION_SEC=0
fi

# Remove persistent file which might still exist from last up time:
rm -f $PERSISTENT_URI_RETRIEVAL_FILE

while [ $STOP_RETRIEVAL_FLAG -eq 0 ] ; do
    $TIME_CMD -p curl --get -k --silent --show-error -o $DEST_FILE $URI >$DURATION_FILE 2>&1
    LINE_EXIT_STATUS=`grep "exited with non-zero status" $DURATION_FILE`
    if [ "x" == "x$LINE_EXIT_STATUS" ] ; then
        RET=0
        STOP_RETRIEVAL_FLAG=1
    else
        # retrieval was not successfull:
        WGET_DURATION_SEC=`grep "real " $DURATION_FILE |sed -e 's/real \([0-9]*\)\.[0-9]*/\1/'`
        PASSED_TIME_SEC=`expr $PASSED_TIME_SEC + $WGET_DURATION_SEC`
        NEXT_PASSED_TIME_SEC=`expr $PASSED_TIME_SEC + $SLEEP_TIME_SEC`
        if [ $NEXT_PASSED_TIME_SEC -gt $MAX_DURATION_SEC ] ; then
            RET=`echo $LINE_EXIT_STATUS |sed -e 's/[^0-9]*\([0-9]*\).*/\1/g'`
            STOP_RETRIEVAL_FLAG=1
        fi
        if [ $MAX_DURATION_SEC -eq 0 ] ; then
            # Wait infinitive, when MAX_DURATION_SEC is zero:
            STOP_RETRIEVAL_FLAG=0
        fi
        if [ $STOP_RETRIEVAL_FLAG -eq 0 ] ; then
            if [ $FIRST_TIME_FAILED_FLAG -eq 1 ] ; then
                FIRST_TIME_FAILED_FLAG=0
                CreatePersistentFile
            fi
            sleep $SLEEP_TIME_SEC
            PASSED_TIME_SEC=`expr $PASSED_TIME_SEC + $SLEEP_TIME_SEC`
        fi
    fi 
done

# The PERSISTENT_URI_RETRIEVAL_FILE might exist. Timeout or success occured, delete this file:
rm -f $PERSISTENT_URI_RETRIEVAL_FILE

exit $RET
