#!/bin/sh

# Include the calibration definition and helper functions
source /etc/Counter/CalibDefs.sh

source  /etc/init.d/rc1.d/_HelperFunctions/XmlParameter


if [ $# -lt 2 ]
then
    echo "Missing parameter, Usage: $0 <video_rec_dir> <video_base_name> {<AppID> <MsgID>}"
    echo "If AppID/MsgID is supplied, a message with the full filename will send via MsgBroker."
    exit 1
fi


RecDir=$1
FileBaseName=$2

SEND_MSG=0
if [ $# -ge 4 ] ; then
    SEND_MSG=1
    APP_ID=$3
    MSG_ID=$4
fi

RecDir=${RecDir}/${FileBaseName}
ParamDir=${RecDir}/${FileBaseName}_params
SceneFile="${RecDir}/${FileBaseName}.scene"
PrPointFile="${ParamDir}/PrincipalPoint.csv"

# ### This is a function. It is not indented because of the here script within it.
worker() {
mkdir -p "${ParamDir}"

cd "${ParamDir}"

# Link files to ..Counter/config:
for file in countingpolygons_values.xml ip_extcalib_params_values.xml ip_zonemonitoring_values.xml aps_ip_elevationmap_params_values.xml ip_elevmapaoi_values.xml dispmask.bit ip_coordtrafo_params_values.xml aps_master_slave_params_values.xml; do
    # we only create links to files that actually exist (param file set is differrent between projects)
    fullFilePath="/var/Counter/config/${file}"
    if [ -f ${fullFilePath} ]
    then
        ln -s ${fullFilePath} ${file}
    fi
done

# Link to calibration files:
for file in intern_relative_calib_values.xml intern_640x480.ini ; do
    ln -s ${CALDEF_DIR_TMP}${file} ${file}
done

# If Multisensorfusion is active, create stitched image and principal point information
master_slave_params_file="/var/Counter/config/aps_master_slave_params_values.xml"
if [ -f "$master_slave_params_file" ]
then
    MSF_MODE=`GetParamValue aps_master_slave_params MasterSlaveMode`
else
    MSF_MODE=0
fi
if [ ${MSF_MODE} -eq 1 ]
then
    CreateStitchedImgSnapshot.sh ${RecDir}/stitched_img.png
    PRPOINTX=`/sbin/Stitcher -i | cut -d" " -f13 | cut -c 2-8`
    PRPOINTY=`/sbin/Stitcher -i | cut -d" " -f14 | cut -c 1-7`
    cat > ${PrPointFile} <<EOF2
${PRPOINTX} ${PRPOINTY}
EOF2
    
fi

# create scene file
cat > ${SceneFile} <<EOF1
[
    {
        filename = "${FileBaseName}.avi";
        params =
        {
            useStampFile = true;
        }
    },
    {
        filename = "${FileBaseName}.rec";
        params =
        {
            frameMode = true;
        }
    }
]
EOF1

cd ${RecDir}
ln -s ../${FileBaseName}.avi ${FileBaseName}.avi
gzip -c ../${FileBaseName}.rec > ${FileBaseName}.rec.gz

cd ..
tar cf ${FileBaseName}.tar -h ${FileBaseName}

# send the "video file is available on storage" message broker message
APP_ID_VIDEORECORDING_D=23
APC_VIDEORECORDING_D_MSG_ID_VIDEOFILE_READY=6
/usr/local/bin/APC_SendMsg ${APP_ID_VIDEORECORDING_D} ${APC_VIDEORECORDING_D_MSG_ID_VIDEOFILE_READY}

# Delete files that are now inside tarball:
rm -rf `find . -maxdepth 1 -name ${FileBaseName}\* |grep -v ${FileBaseName}.tar`

if [ 1 -eq ${SEND_MSG} ] ; then
    FILENAME=`pwd`/${FileBaseName}.tar
    # Make sure the string contains an trailing null byte:
    FILENAME=${FILENAME}"\x00"
    FILENAME_IN_HEX=`echo -e -n ${FILENAME}  |od -t x4 |cut -c9- |tr '\n' ' ' |sed -e's/ *$//' -e's/ / 0x/g' -e's/^/0x/'`
    /usr/local/bin/APC_SendMsg ${APP_ID} ${MSG_ID} ${FILENAME_IN_HEX}
fi
}

worker &

