#!/bin/sh

#################################################################################################
#   (c) 2016 by Hella Aglaia Mobile Vision GmbH
#   Author: Andrej Wunrau
#   No usage without written permission.
#   All rights reserved.
#
#   Module: WirelessServices
#   File: btGetStatus.sh
#
#   Description:    
#
#       Script returns status informations concerning the wireless services
#       functionality depending on the specified commando:
#           device          - returns "up" if a working bt device is available in the system, "down" otherwise
#           mac             - returns the mac address of the interface
#       The obtained status information is printed to stdout.
#
#################################################################################################


# import global variables and functions 
. btGlobalVariables.sh
. btGlobalFunctions.sh


# script parameters
INTERFACE=${1}
ARGUMENT=${2}

# usage
usage () {
    log "Usage: ${0} <interface> <device|mac|mode>"
}

# check parameters
if [ $# -eq 2 ]
then
    if  [ ${ARGUMENT} = "device" ]
    then
        dev_state=`is_bluetooth_device_available ${INTERFACE}`
        echo ${dev_state}
        exit 0
    fi

    if  [ ${ARGUMENT} = "mac" ]
    then
        mac=`get_interface_mac ${INTERFACE}`
        echo ${mac}
        exit 0
    fi

    if  [ ${ARGUMENT} = "mode" ]
    then
        mode=`get_current_bluetooth_mode ${INTERFACE}`
        echo ${mode}
        exit 0
    fi

    # unknown parameter
    log "error, unknown argument: ${ARGUMENT}"
    exit 2

else 
    # number of params wrong  
    log "error, wrong number of parameters"
    usage
    exit 1
fi    
