#!/bin/sh

#################################################################################################
#   (c) 2016 by Hella Aglaia Mobile Vision GmbH
#   Author: Andrej Wunrau
#   No usage without written permission.
#   All rights reserved.
#
#   Module: WirelessServices
#   File: btGlobalFunctions.sh
#
#   Description:    
#
#       Script holds a set of functions that are shared between
#       the different script of the wireless services module (bluetooth).
#
#################################################################################################

# set DEBUG=1 to write logs to stderr (in addition to logs in /var/log/messages)
DEBUG=0


###################################################################################################################################
# logging functions

# logs to std err
logToConsole () { 
    echo -e "$0, $@" 1>&2;
}

# logs to /var/log/messages
log () {
    logger -p user.error "$0: $1"
    # if DEBUG is 1 -> also log to console
    if [ ${DEBUG} -eq 1 ]
    then
        logToConsole $1
    fi
}



###################################################################################################################################
# dongle status functions
is_bluetooth_device_available ()
{
    if [ $# -eq 1 ]
    then
        INTERFACE=$1
        if [ INTERFACE == "" ]
        then
            result=`echo "down"`
        else
            result=`if [ -e /sys/class/bluetooth/${INTERFACE} ]; then echo "up"; else echo "down"; fi`
        fi
        echo ${result}
        return 0
    else
        log "Error: {$0}, wrong number of parameters on call to function is_bluetooth_device_available."
        return 1 
    fi
}


get_interface_mac ()
{
    if [ $# -eq 1 ]
    then
        INTERFACE=$1
        if [ INTERFACE == "" ]
        then
            result=""
        else
            result=`cat /sys/class/bluetooth/${INTERFACE}/address`
            echo ${result}
            return 0
        fi
    else
        log "Error: {$0}, wrong number of parameters on call to function get_interface_mac."
        return 1
    fi
}


######################################################################################################################################
# bluetooth mode functions

is_process_active ()
{
    PROC_NAME=$1

    if [ $# -ne 1 ]
    then
        log "Error: wrong number of parameters"
        return 1
    fi

    RES=`ps | grep ${PROC_NAME} | wc -l `
    if [ ${RES} -gt 1 ]
    then
        echo "yes"
    else
        echo "no"
    fi

    return 0
}


get_current_bluetooth_mode ()
{
    INTERFACE=$1

    if [ $# -ne 1 ]
    then
        log "Error: wrong number of parameters"
        return 1
    fi

    device_state=`is_bluetooth_device_available ${INTERFACE}`

    if [ ${device_state} = "down" ]
    then 
        # if device_state is down -> off mode
        echo "MODE_OFF"
        return 0
    else
        TRACKING_DAEMON_ACTIVE=`is_process_active BluetoothTracking_d`

        if [ ${TRACKING_DAEMON_ACTIVE} = "yes" ]
        then
            echo "MODE_WIRELESS_TRACKING"
            return 0
        else             
            echo "MODE_OFF"
            return 0
        fi
    fi

    # no mode matched??
    echo ""
    log "Error: could not determine current bluetooth services mode!"
    return 1
}