#!/bin/sh

#################################################################################################
#   (c) 2016 by Hella Aglaia Mobile Vision GmbH
#   Author: Andrej Wunrau
#   No usage without written permission.
#   All rights reserved.
#
#   Module: WirelessServices
#   File: btModeTracking.sh
#
#   Description:    
#
#       Script holds all functionality concerning the bluetooth tracking mode of wireless services.
#       Use this script to either start, restart or stop MODE_WIRELESS_TRACKING. When
#       started script communicates a list of clients that are present in the vicinity of the device.
#
#################################################################################################


# import global variables and functions 
. btGlobalVariables.sh
. btGlobalFunctions.sh


usage()
{
    log "Usage: $0 <bt-interface> <start|stop|restart>"
}


start_tracking_mode ()
{
    INTERFACE=$1

    if [ $# -ne 1 ]
    then
        log "Error: wrong number of parameters"
        return 1
    else
        # start bluetooth tracking daemon
        /sbin/BluetoothTracking_d
        if [ $? -ne 0 ]
        then
            log "Error: call to stop_tracking_mode failed"
            return 2
        fi
    fi
    return 0
}

stop_tracking_mode ()
{
    INTERFACE=$1

    if [ $# -ne 1 ]
    then
        log "Error: wrong number of parameters"
        return 1
    else
        # stop wireless tracking daemon
        killall BluetoothTracking_d
    fi
    return 0
}

restart_tracking_mode ()
{
    INTERFACE=$1

    if [ $# -ne 1 ]
    then
        log "Error: wrong number of parameters"
        return 1
    else

        stop_tracking_mode ${INTERFACE}
        if [ $? -ne 0 ]
        then
            log "Error: call to stop_tracking_mode failed"
            return 2
        else
            sleep 1
            start_tracking_mode ${INTERFACE}
            if [ $? -ne 0 ]
            then
                log "Error: call to start_tracking_mode failed"
                return 3
            fi
        fi
    fi
}



#################################################################################################
# script starts here
#################################################################################################
if [ $# -ne 2 ]
then
    log "Error, wrong number of parameters"
    usage
    exit 1
else 
    # arguments
    INTERFACE=$1
    ARGUMENT=$2

    # start operation depending on argument
    if   [ ${ARGUMENT} = "start" ]
    then
        start_tracking_mode ${INTERFACE}
        START_RESULT=$?
        if [ ${START_RESULT} -ne 0 ]
        then
            log "Error: start_tracking_mode failed with error code: ${START_RESULT}"
            exit 4
        fi
    elif [ ${ARGUMENT} = "stop" ]
    then
        stop_tracking_mode ${INTERFACE}
        STOP_RESULT=$?
        if [ ${STOP_RESULT} -ne 0 ]
        then
            log "Error: stop_tracking_mode failed with error code: ${STOP_RESULT}"
            exit 5
        fi
    elif [ ${ARGUMENT} = "restart" ]
    then
        restart_tracking_mode ${INTERFACE}
        RESTART_RESULT=$?
        if [ ${RESTART_RESULT} -ne 0 ]
        then
            log "Error: restart_tracking_mode failed with error code: ${RESTART_RESULT}"
            exit 6
        fi
    else
        # undefined argument used
        log "Error, undefined argument used."
        usage
        exit 2
    fi
fi

