#!/bin/sh


########################################################################
#
# Clean all Data File Recording data files
#
########################################################################

# DEFS
RESTART_DAEMON_SCRIPT="/sbin/dfr_handling.sh"
MAX_WAIT_TIME_SEC=240

# Get path to Data File Recording data directory (depends on SDCard)
VALS=`/sbin/GetStorePath.sh`
RES=$?
if [ $RES -eq 0 ] ; then
    # evaluate VALS ($1 = SDCard availability, $2 = data directory)
    set ${VALS}
    SDCARD_AVAIL=$1
    DATA_DIR=$2
    if [ $SDCARD_AVAIL -eq 0 ] ; then
        # 0 = no SDCard, set-up command line parameter
        DFR_DATA_DIR=${DATA_DIR}/DFR/data
    elif [ $SDCARD_AVAIL -eq 1 ] ; then
        # 1 = SDCard
        DFR_DATA_DIR=${DATA_DIR}/DFR/data
    else
        echo "unknown SDCard mode (= ${SDCARD_AVAIL})"
        exit 1
    fi
else
    # error occured, do not start DFR application
    echo "script dfr_get_store_path.sh returned an error  (= ${RES})"
    exit 1
fi

if [ ! -d ${DFR_DATA_DIR} ] ; then
    echo "DFR data directory not exist: ${DFR_DATA_DIR}" 1>&2
    exit 1
fi

# Send a SIGTERM to a current running daemon and
# wait (max. 240 seconds) for daemon termination.
DFR_DAEMON_BIN_NAME="APC_DataFileRecording_d"
PID=`pidof -s ${DFR_DAEMON_BIN_NAME}`
kill -15 ${PID} >/dev/null 2>&1

CNT=1
while [ $CNT -lt $MAX_WAIT_TIME_SEC ] ; do
    pidof -s ${DFR_DAEMON_BIN_NAME}
    RES=$?
    if [ $RES -ne 0 ] ; then
        break
    fi
    sleep 1 #sleep one second
    CNT=`expr $CNT + 1`
done


# delete all csv files (must end on .csv) in data directory
rm -f ${DFR_DATA_DIR}/*.csv


# Restart daemon (NOTE: daemon terminates if disabled by parameterization)
/bin/sh ${RESTART_DAEMON_SCRIPT} ${SDCARD_AVAIL} ${DATA_DIR}


exit 0
