#!/bin/sh

########################################################################
#
# handling for Data File Recording
#  - start-up
#  - create storage location for data files
#  - max. number of data files
#  - max. allowed disk space size
#
########################################################################

########################################################################
# Defs / Variables
########################################################################
# daemon binary
DAEMON_BIN="/sbin/APC_DataFileRecording_d"
# directory and FQFN for "last used file id" file, note: currently constant
ID_DIR="/var/log/HAGL/DFR/"
LAST_FILE_ID_FILE=${ID_DIR}"last_file_id"

# directories for different data files storage location
DATA_DIR="/DFR/data/"

# maximal usable disk space in byte (2 MByte for flash, 100 MByte for SDCard)
MAX_DISK_SPACE_FLASH=2097152
MAX_DISK_SPACE_SDCARD=104857600

# maximal number of data files
MAX_DATA_FILES_FLASH=4000
MAX_DATA_FILES_SDCARD=8000

########################################################################
# Check if last file id file exist, create it with initial value (UINT32_MAX) if not
########################################################################
if [ ! -f ${LAST_FILE_ID_FILE} ] ; then
    # Check if directory exist
    if [ ! -d ${ID_DIR} ] ; then
        mkdir -p ${ID_DIR}
        logger -p user.notice "DFR last file id directory created: ${ID_DIR}"
    fi
    # create and write initial id to file (binary)
    echo -n $'\xFF' > ${LAST_FILE_ID_FILE}
    echo -n $'\xFF' >> ${LAST_FILE_ID_FILE}
    echo -n $'\xFF' >> ${LAST_FILE_ID_FILE}
    echo -n $'\xFF' >> ${LAST_FILE_ID_FILE}
    logger -p user.notice "DFR last file id file created initially: ${LAST_FILE_ID_FILE}"
fi

########################################################################
# Set-up command line arguments for data file recording daemon
# If SDCard is available use it, else use flash
########################################################################
if [ $# -eq 2 ] ; then
    # $1 = SDCard availability, $2 = data directory
    SDCARD_AVAIL=${1}
    DATA_PATH=${2}${DATA_DIR}
    if [ $SDCARD_AVAIL -eq 0 ] ; then
        ARG_DISK_SPACE_BYTE=${MAX_DISK_SPACE_FLASH}
        ARG_NUM_DATA_FILES=${MAX_DATA_FILES_FLASH}
    elif [ $SDCARD_AVAIL -eq 1 ] ; then
        ARG_DISK_SPACE_BYTE=${MAX_DISK_SPACE_SDCARD}
        ARG_NUM_DATA_FILES=${MAX_DATA_FILES_SDCARD}
    else
        logger -p user.error "script dfr_handling.sh got unknown SDCARD mode, Data File Recording application not started."
        exit 1
    fi
else
    logger -p user.error "script dfr_handling.sh got wrong count of params, Data File Recording application not started."
    exit 1
fi

# Create data directory if not exist
if [ ! -d ${DATA_PATH} ] ; then
    mkdir -p ${DATA_PATH}
    logger -p user.notice "dir created: ${DATA_PATH}"
fi

########################################################################
# start daemon
########################################################################
${DAEMON_BIN} -d "${DATA_PATH}" -f "${LAST_FILE_ID_FILE}" -s ${ARG_DISK_SPACE_BYTE} -m ${ARG_NUM_DATA_FILES}
