#!/bin/sh

export PATH=/sbin:/usr/sbin:/bin:/usr/bin

to_fallback()
{
    # Check that we are not running in fallback mode:
    CUR_RFS_ID=`fw_printenv rfsID_SD |sed -e's/.*=//'`
    if [ "x/dev/mmcblk0p5" = "x${CUR_RFS_ID}" ] ; then
        echo "Fallback already set. Terminating."
        exit 2
    fi

    # Save current settings:
    echo last_rfsID_SD         ${CUR_RFS_ID}                                >>${TMP_FILE}
    echo last_kernel_image_no `fw_printenv kernel_image_no |sed  -e's/.*=//'` >>${TMP_FILE}

    # Set variables to fallback partition:
    echo rfsID_SD        /dev/mmcblk0p5  >>${TMP_FILE}
    echo kernel_image_no Ifb             >>${TMP_FILE}
}

to_last_used()
{
    # Check that last_used is set:
    LAST_USED_RFS_ID=`fw_printenv last_rfsID_SD 2>/dev/null |sed -e's/.*=//'`
    if [ -z ${LAST_USED_RFS_ID} ] ; then
        echo "last_rfsID_SD not set. Abort."
        exit 2
    fi
    LAST_KERNEL_IMAGE_NO=`fw_printenv last_kernel_image_no 2>/dev/null |sed -e's/.*=//'`
    if [ -z ${LAST_KERNEL_IMAGE_NO} ] ; then
        echo "last_kernel_image_no not set. Abort."
        exit 2
    fi

    # Set variables to last_used:
    echo rfsID_SD        ${LAST_USED_RFS_ID}     >>${TMP_FILE}
    echo kernel_image_no ${LAST_KERNEL_IMAGE_NO} >>${TMP_FILE}

    # Remove saved last_used U-Boot variables:
    echo last_rfsID_SD        >>${TMP_FILE}
    echo last_kernel_image_no >>${TMP_FILE}
}

# ### main():


if [ $# -ne 1 ] ; then
    echo 'One parameter needed: [to_fallback|to_last_used]'
    CUR_RFS_ID=`fw_printenv rfsID_SD |sed -e's/.*=//'`
    if [ "x/dev/mmcblk0p5" = "x${CUR_RFS_ID}" ] ; then
        echo "Currently set: fallback"
    else
        echo "Currently set: last_used"
    fi
    exit 1
fi

TMP_FILE=`mktemp`

if [ "$1" = "to_fallback" ] ; then
    to_fallback
elif [ "$1" = "to_last_used" ] ; then
    to_last_used
else
    echo "Parameter is neither to_fallback nor to_last_used. Abort."
    exit 1
fi

mount -oremount,rw /boot

fw_setenv -s ${TMP_FILE}
rm ${TMP_FILE}

mount -oremount,ro /boot
