#!/bin/sh

############################################################
#
# Script function for video snapshot creation
#
# fnRecordVideoSnapshots()
#  - creates 3 images as png:
#    - left original
#    - right rectified
#    - disparity map
#
#  - saves these images in directory passed as argument
# 
############################################################

fnEchoErr() { 
    echo "$@" 1>&2;
}

fnRecordVideoSnapshots() {
	SNAPSHOT_DIR=$1						# pass directory to save images in as argument
    VID_DEV_ORIGINAL_LEFT=/dev/video0
    VID_DEV_RECTIFIED_RIGHT=/dev/video3
    VID_DEV_DISPARITY_MAP=/dev/video4

    mkdir -p ${SNAPSHOT_DIR} >/dev/null 2>&1
    RES_TMP=$?
    if [ ${RES_TMP} -ne 0 ] ; then
        logger -p user.error "$0: could not create tmp directory: '${SNAPSHOT_DIR}'"
        fnEchoErr "could not create tmp directory: '${SNAPSHOT_DIR}'"
    else 
        # env vars for GSTreamer
        export GST_PLUGIN_SYSTEM_PATH_1_0=/lib/gstreamer-1.0
        export GST_PLUGIN_PATH_1_0=/lib/gstreamer-1.0
        
        # left original image
        gst-launch-1.0 v4l2src num-buffers=1 device=${VID_DEV_ORIGINAL_LEFT} \
        ! videocrop top=1 left=0 right=0 bottom=1 \
        ! video/x-raw, format=GRAY16_LE, interlaced=false, width=640, height=480 \
        ! bitshifter amount=4   \
        ! videoconvert ! pngenc \
        ! filesink location=${SNAPSHOT_DIR}/snapshot_original_left.png

        RES_TMP=$?
        if [ ${RES_TMP} -ne 0 ] ; then
            logger -p user.error "$0: could not get left vga image"
            fnEchoErr "could not get left vga image"
            return 1
        else 
            # right rectified image
            gst-launch-1.0 v4l2src num-buffers=1 device=${VID_DEV_RECTIFIED_RIGHT} \
            ! videocrop top=1 left=0 right=0 bottom=1 \
            ! video/x-raw, format=GRAY16_LE, interlaced=false, width=640, height=480 \
            ! bitshifter amount=4   \
            ! videoconvert !  pngenc \
            ! filesink location=${SNAPSHOT_DIR}/snapshot_rectified_right.png

            RES_TMP=$?
            if [ ${RES_TMP} -ne 0 ] ; then
                logger -p user.error "$0: could not get right rectified image"
                fnEchoErr "could not get right rectified image"
                return 2
            else 
                # disparity map
                gst-launch-1.0 v4l2src num-buffers=1 device=${VID_DEV_DISPARITY_MAP} \
                ! videocrop top=1 left=0 right=0 bottom=1 \
                ! video/x-raw, format=GRAY16_LE, interlaced=false, width=640, height=480 \
                ! bitshifter amount=4   \
                ! videoconvert !  pngenc \
                ! filesink location=${SNAPSHOT_DIR}/snapshot_dispmap.png

                RES_TMP=$?
                if [ ${RES_TMP} -ne 0 ] ; then
                    logger -p user.error "$0: could not get disparity map"
                    fnEchoErr "could not get disparity map"
                    return 3
                fi
            fi
        fi
    fi
    return 0
}
