#!/bin/sh

#################################################################################################
#   (c) 2018 by Hella Aglaia Mobile Vision GmbH
#   Author: Andrej Wunrau
#   No usage without written permission.
#   All rights reserved.
#
#   Description:    
#
#       Script tests if a ftp/sftp connection is working. Connection is parametrized
#       via script arguments.
#
#################################################################################################


DEBUG=1

HOSTNAME=`hostname`

TESTFILE_NAME="ConnectionTest_"${HOSTNAME}


# logs to std err
logToConsole () { 
    echo -e "$0, $@" 1>&2;
}

# logs to /var/log/messages
log () {
    logger -p user.error "$0: $1"
    # if DEBUG is 1 -> also log to console
    if [ ${DEBUG} -eq 1 ]
    then
        logToConsole $1
    fi
}


usage ()
{
    log "Usage: "
    log "           $0 <protocol> <ip-addr> <portNo> <user> <pw> [<dirname>]"
    log "arguments: "
    log "           protocol:   ftp or sftp"
    log "           ip-addr:    IP address of server " 
    log "           portNo:     server port number"
    log "           user:       username"
    log "           pw:         password"
    log "           dirname:    name of server sub directory (optional)"
}



#################################################################################################
# script starts here
#################################################################################################


#################################################################################################
# argument handling
#################################################################################################

# less than 5 arguments given, failure
if [ $# -lt 5 ]
then
    log "Error, wrong number of parameters in call to script!"
    usage
    exit 1
fi 

# 5 or 6 arguments
if [ $# -le 6 ]
then
    # save possible optional argument
    if [ $# -eq 6 ]
    then  
        SERVER_DIR=$6
    else
        SERVER_DIR="."
    fi

    # save the mandatory arguments
    PROTOCOL=$1
    SERVER_IP=$2
    SERVER_PORT=$3
    USER_NAME=$4
    USER_PW=$5

else
    log "Error, wrong number of parameters in call to script!"
    usage
    exit 2
fi


#################################################################################################
# argument validation
#################################################################################################

# validate protocol argument
if [ $PROTOCOL != "ftp" ]
then
    if [ $PROTOCOL != "sftp" ]
    then
        log "Error, wrong protocol argument!"
        usage
        exit 3
    fi
fi

# we assume that all other arguments were already validated (e.g: HMI), or can't be validated


#################################################################################################
# create testfile
#################################################################################################

DATE_STRING=$(date)
RANDOM_STRING=$RANDOM
TEST_STRING="Testfile for checking ftp/sftp connection. Date: ${DATE_STRING} Random: ${RANDOM_STRING}"

echo ${TEST_STRING} > /tmp/${TESTFILE_NAME}


#################################################################################################
# test connection
#################################################################################################

if [ $PROTOCOL = "ftp" ]
then
    #ftp
    ftpput -u ${USER_NAME} -p ${USER_PW} -P ${SERVER_PORT} ${SERVER_IP} ${SERVER_DIR}/${TESTFILE_NAME} /tmp/${TESTFILE_NAME}
    RESULT=$?
else
    #sftp
    export SSHUSER=${USER_NAME}
    export SSHPASS=${USER_PW}
    export SSHPORT=${SERVER_PORT}
    export SFTP_SERVER=${SERVER_IP}
    export LOCAL_PATH=/tmp/${TESTFILE_NAME}
    export REMOTE_PATH=${SERVER_DIR}/${TESTFILE_NAME}
    
    # Call the upload script
    sftp_upload.sh

    RESULT=$?
fi

return ${RESULT}
