#!/bin/sh

# Exit code definition.
EXIT_OK=0
EXIT_ERR=1

# Log file FQFN for the "rolling reboot counter" value
RR_CNT_FILE=/var/log/rolling_reboot_cnt.log

#
# Script file name.
#
SCRIPT_NAME=$(basename $0)


#
# Get and check arguments.
# TODO: something like this: (*[^0-9]*|'') echo not a number;; ??
#
if [ 1 -ne $# ] ; then
    logger -p error -t ${SCRIPT_NAME} "Invalid number of arguments, abort."
    exit ${EXIT_ERR}
fi
VALUE=$1
if [ "${VALUE}" -eq "${VALUE}" ] 2>/dev/null ; then
    : # avoid no-op
else
    logger -p error -t ${SCRIPT_NAME} "Input argument must be a number, abort."
    exit ${EXIT_ERR}
fi


#
# Protect the critical section in this script:
# - read and write the rolling reboot counter file
# NOTE: currently without a timeout !
#
LCK="/tmp/${SCRIPT_NAME}.LCK";
exec 111>$LCK;
flock -x 111;


#
# Update value in file.
#
if [ ! -f ${RR_CNT_FILE} ] ; then
    # File not exist, create it with incoming value or 0 and exit.
    # Clip value to greater or equal 0.
    if [ ${VALUE} -lt 0 ] ; then
        VALUE=0
    fi
    echo ${VALUE} > ${RR_CNT_FILE}
else
    # File exist, get current value, calculate the new value and write to file.
    CUR_VAL=`cat ${RR_CNT_FILE}`
    NEW_VAL=$(expr ${CUR_VAL} + ${VALUE})
    # Clip new value to greater or equal 0.
    if [ ${NEW_VAL} -lt 0 ] ; then
        NEW_VAL=0
    fi
    # Write new value to file.
    echo ${NEW_VAL} > ${RR_CNT_FILE}
fi

exit ${EXIT_OK}

