#!/bin/sh

#################################################################################################
#   (c) 2016 by Hella Aglaia Mobile Vision GmbH
#   Author: Andrej Wunrau
#   No usage without written permission.
#   All rights reserved.
#
#   Module: WirelessServices
#   File: wifiGetStatus.sh
#
#   Description:    
#
#       Script returns status informations concerning the wireless services
#       functionality depending on the specified commando:
#           license         - returns "yes" if wireless services license is installed on the divice, "no" otherwise
#           device          - returns "up" if a working wifi device is available in the system, "down" otherwise
#           if-state        - returns "up" if the interface that is linked to the wifi devise is up, "down" otherwise
#           connection      - return "up" if a connection to an access point is established, "down" otherwise
#           ip              - returns the current ip address that is configured for the interface
#           mac             - returns the mac address of the interface
#           mode            - returns the currently active wireless services mode
#       The obtained status information is printed to stdout.
#
#################################################################################################


# import global variables and functions 
. wifiGlobalVariables.sh
. wifiGlobalFunctions.sh


# script parameters
INTERFACE=${1}
ARGUMENT=${2}

# usage
usage () {
    log "Usage: ${0} <interface> <license|device|if-state|connection|ip|mac|mode|accesspoint_password|data_access_password>"
}

# check parameters
if [ $# -eq 2 ]
then
    if  [ ${ARGUMENT} = "license" ]
    then
        lic_state=`is_wifi_license_available`
        echo ${lic_state}
        exit 0
    fi

    if  [ ${ARGUMENT} = "device" ]
    then
        dev_state=`is_wifi_device_available ${INTERFACE}`
        echo ${dev_state}
        exit 0
    fi

    if  [ ${ARGUMENT} = "if-state" ]
    then
        wifi_state=`get_interface_state ${INTERFACE}`
        echo ${wifi_state}
        exit 0
    fi

    if  [ ${ARGUMENT} = "connection" ]
    then
        conn_state=`get_connection_state ${INTERFACE}`
        echo ${conn_state}
        exit 0
    fi

    if  [ ${ARGUMENT} = "ip" ]
    then
        ip=`get_interface_ip ${INTERFACE}`
        echo ${ip}
        exit 0
    fi

    if  [ ${ARGUMENT} = "mac" ]
    then
        mac=`get_interface_mac ${INTERFACE}`
        echo ${mac}
        exit 0
    fi

    if  [ ${ARGUMENT} = "mode" ]
    then
        mode=`get_current_wirless_mode ${INTERFACE}`
        echo ${mode}
        exit 0
    fi

    if  [ ${ARGUMENT} = "accesspoint_password" ]
    then
        wpa_psk=`get_option_from_config_file ${GLOBAL_HOSTAPD_CONF} "wpa_psk" "="`
        if [ -z ${wpa_psk} ]
        then
            echo "no"
        else
            echo "yes"
        fi
        exit 0
    fi

    if  [ ${ARGUMENT} = "data_access_password" ]
    then

        if [ -e ${GLOBAL_WIFI_ACCESS_CONF} ]
        then
            echo "yes"
        else
            echo "no"
        fi
        exit 0
    fi
   
    # unknown parameter
    log "error, unknown argument: ${ARGUMENT}"
    exit 2

else 
    # number of params wrong  
    log "error, wrong number of parameters"
    usage
    exit 1
fi    
