#!/bin/sh

# Add AllowUsers entry at the end of sshd_config, if it exists.
#
# Preconditions:
# 1.) The entries InUse and SlaveIP should be separated in different lines.
# 2.) These lines should constist of a name value pair separated by spaces and/or tabs.
#
# TODO: 
# Eliminate the preconditions and read general xml files.

# logger -p user.notice "$0 called"

# Send signal to a process
killAndWait() 
{
    SIGNAL=$1
    PROCESS=$2
    RETRIES=10

    # Stop ssh daemon 
    # Remark: 
    # We do not want to terminate existing remote ssh sessions. So we match against the exact 
    # complete command line without command line options (these command line includes a space 
    # at the end)
    pkill $SIGNAL -xf $PROCESS'\s*'

    TRY=0
    while [ $TRY -lt $RETRIES ] ; do
        pgrep -xf $PROCESS'\s*'
        if [ $? -ne 0 ] ; then
            return 0
        fi
        sleep 1
        TRY=$(expr $TRY + 1)
    done
    
    pgrep -xf $PROCESS'\s*'
    if [ $? -ne 0 ] ; then
        return 0
    fi
    
    return 1
}

############################################################
# Define files
############################################################
SSHD=sshd
SSHDFULLPATH=/usr/sbin/$SSHD
SSHD_CONFIGFILE="/var/Counter/DeviceSpecific/sshd_config"

if [ ! -f $SSHD_CONFIGFILE ] ; then
    # Ok, do nothing.
    exit 0
fi

FUSION_PARAMFILE="/var/Counter/config/aps_master_slave_params_values.xml"
FUSION_METAFILE="/etc/Counter/ParamMetaFiles/aps_master_slave_params_meta.xml"

SSH_USERS="root"
SSH_RESTRICTEDUSER="mbproxy"

IPLIST=""

FUSION_MODE=$(GetValueFromXmlFile -k MasterSlaveMode -v ${FUSION_PARAMFILE} -m ${FUSION_METAFILE})
if [ ${FUSION_MODE} -eq 1 ] ; then
    # Master
    INUSE="0"
    while read -r line
    do
        # Does the line include the InUse flag?
        echo $line | grep "name=\"InUse\"" > /dev/null
        if [ $? -eq 0 ] ; then
            # Extract the InUse flag
            INUSE=$(echo $line | sed -E -e 's/.*name="InUse"\s+value="(.)".*/\1/g')
        elif [ "$INUSE" = "1" ] ; then
            # Does the line include the IP?
            echo $line | grep "name=\"SlaveIP\"" > /dev/null
            if [ $? -eq 0 ] ; then 
                # Extract the IP
                IP=$(echo $line | sed -E -e 's/.*name="SlaveIP"\s+value="(.*)".*/\1/g')
                # Append to list
                IPLIST="$IPLIST $SSH_RESTRICTEDUSER@$IP"
            fi
        fi
    done < $FUSION_PARAMFILE
fi

############################################################
# Modify allowed users and IPs in sshd_config file
############################################################

# Remove AllowUsers Entry
sed -i "s/^AllowUsers.*$//g" $SSHD_CONFIGFILE

# Remove empty lines at the end of the file
sed -i -e :a -e '/^\n*$/{$d;N;ba' -e '}' $SSHD_CONFIGFILE

# Add AllowUsers entry at the end of the file.
# For stand-alone and slave devices this entry should only 
# include the user root.
echo "" >> $SSHD_CONFIGFILE
echo "AllowUsers $SSH_USERS$IPLIST" >> $SSHD_CONFIGFILE

# Debug
tail -n1 $SSHD_CONFIGFILE

############################################################
# Restart ssh daemon
############################################################

if [ x"$1" != x"NoDaemonRestart" ] ; then 
    # Terminate or kill the ssh daemon
    killAndWait -6 $SSHDFULLPATH
    if [ $? -ne 0 ] ; then 
        killAndWait -9 $SSHDFULLPATH
    fi

    killAndWait -6 $SSHD
    if [ $? -ne 0 ] ; then 
        killAndWait -9 $SSHD
    fi

    # Start ssh daemon
    $SSHDFULLPATH
fi

# Ok
exit 0
