#!/bin/sh

# Send signal to a process
killAndWait() 
{
    # echo "$0 $@"
    
    SIGNAL=$1
    PROCESS=$2
    RETRIES=10

    pkill $SIGNAL -x $PROCESS

    TRY=0
    while [ $TRY -lt $RETRIES ] ; do
        pgrep -x $PROCESS
        if [ $? -ne 0 ] ; then
            return 0
        fi
        sleep 1
        TRY=$(expr $TRY + 1)
    done
    
    pgrep -x $PROCESS
    if [ $? -ne 0 ] ; then
        return 0
    fi
    
    return 1
}

PROXY=/sbin/MsgBrokerProxy_d

# Start message broker proxy, if needed
# Set the proxy parameters dependent on the mode (master or slave)
FUSION_PARAMFILE=/var/Counter/config/aps_master_slave_params_values.xml
FUSION_METAFILE=/etc/Counter/ParamMetaFiles/aps_master_slave_params_meta.xml
FUSION_MODE=$(GetValueFromXmlFile -k MasterSlaveMode -v ${FUSION_PARAMFILE} -m ${FUSION_METAFILE})

if [ -z $FUSION_MODE ] ; then
    # Unknown new fusion mode
    # Error! Parameter file seems to be corrupt!
    logger -p user.err "$0: Unknown fusion mode"
    FUSION_MODE=3
fi

PROXY_PARAMFILE=/var/Counter/config/aps_messagebroker_proxy_params_values.xml
# TODO:
# Use these locations for the parameter files later
# PROXY_PARAMFILE_MASTER=/etc/Counter/ParamFilesFusion/aps_messagebroker_proxy_params_values_master.xml
# PROXY_PARAMFILE_SLAVE=/etc/Counter/ParamFilesFusion/aps_messagebroker_proxy_params_values_slave.xml
PROXY_PARAMFILE_MASTER=/usr/local/bin/aps_messagebroker_proxy_params_values_master.xml
PROXY_PARAMFILE_SLAVE=/usr/local/bin/aps_messagebroker_proxy_params_values_slave.xml

# Is the proxy running? 0 = not running; 1 = running
PID=$(pgrep -x $PROXY)
test -z $PID
IS_PROXY_RUNNING=$? 

# Determine the current fusion mode
if [ $IS_PROXY_RUNNING -eq 1 ] ; then 
    diff $PROXY_PARAMFILE $PROXY_PARAMFILE_MASTER > /dev/null
    if [ $? -eq 0 ] ; then
        CURRENT_FUSION_MODE=1
    else
        CURRENT_FUSION_MODE=2
    fi
else
    # Standalone
    CURRENT_FUSION_MODE=0
fi

logger -p user.notice "$0: Fusion mode: current = $CURRENT_FUSION_MODE, new = $FUSION_MODE"
# echo "Fusion mode: current = $CURRENT_FUSION_MODE, new = $FUSION_MODE"
                                                                                                     
# Nothing to do if the mode does not change. 
# Except we are in client mode. In this case ip changes of the master are currently not recognized. (Patch)
if [ ${FUSION_MODE} -eq ${CURRENT_FUSION_MODE} ] && [ ${FUSION_MODE} -ne 2 ] ; then
    exit 0
fi

if [ $IS_PROXY_RUNNING -eq 1 ] ; then 
    # Terminate the proxy
    logger -p user.notice "$0: Terminating proxy"
    killAndWait -6 $PROXY
    if [ $? -ne 0 ] ; then 
        # Kill the proxy
        logger -p user.notice "$0: Killing proxy"
        killAndWait -9 $PROXY
    fi
fi

if [ ${FUSION_MODE} -eq 1 ] ; then
  # Master
  cp $PROXY_PARAMFILE_MASTER $PROXY_PARAMFILE
elif [ ${FUSION_MODE} -eq 2 ] ; then
  # Slave
  cp $PROXY_PARAMFILE_SLAVE $PROXY_PARAMFILE
fi

# Restart proxy if needed
if [ ${FUSION_MODE} -eq 1 ] || [ ${FUSION_MODE} -eq 2 ] ; then
  # Master or slave mode
  logger -p user.notice "$0: Starting proxy"
  $PROXY
fi

exit 0
