#!/usr/bin/env python

import os
import sys
import syslog

sys.path.append('/opt/WebServices/server/lib')

from ParamHandling.parameters import Parameters

# verbose syslog (set to "LOG_NOTICE" for verbose output)
LOG_LVL = syslog.LOG_INFO
#LOG_LVL = syslog.LOG_NOTICE


#
# XML value file name is argument 1
#
xmlValueFileName = sys.argv[1]
syslog.syslog(LOG_LVL, 'value file argument: {0}'.format(xmlValueFileName))


#
# Get XML value file FQFN
#
xmlValueFileFQFN = '/var/Counter/config/' + xmlValueFileName
syslog.syslog(LOG_LVL, 'XML value file FQFN: {0}'.format(xmlValueFileFQFN))


#
# Check if XML value FQFN file exist
#
if ( not os.path.isfile(xmlValueFileFQFN) ):
    syslog.syslog(syslog.LOG_ERR, 'XML value file not exist: {0}'.format(xmlValueFileFQFN))
    sys.exit(1)


#
# XML value file argument must ends with '_values.xml'
#
if ( not xmlValueFileName.endswith('_values.xml') ):
    syslog.syslog(syslog.LOG_ERR, 'value file not ends with \'_values.xml\': {0}'.format(xmlValueFileName))
    sys.exit(2)


#
# Get XML meta file FQFN 
#
xmlMetaFileFQFN = '/etc/Counter/ParamMetaFiles/' + xmlValueFileName.replace('_values.xml', '_meta.xml', 1)
syslog.syslog(LOG_LVL, 'XML meta file FQFN: {0}'.format(xmlMetaFileFQFN))


#
# Check if XML meta FQFN file exist
#
if ( not os.path.isfile(xmlMetaFileFQFN) ):
    syslog.syslog(syslog.LOG_ERR, 'XML meta file not exist: {0}'.format(xmlMetaFileFQFN))
    sys.exit(3)


#
# Get value for 'name' : 'identifier' in paramSet dict
#
idParamFileStr = xmlValueFileName.replace('_values.xml', '', 1)
syslog.syslog(LOG_LVL, 'idParamFileStr: {0}'.format(idParamFileStr))


#
# Get id value from paramSet dict
#
paramIdFound = False
paramIdValue = None
for i in Parameters.paramSets.items():
    if ( len(i) is 2 ):
        if ( ('name' in i[1]) and ('id' in i[1])  ):
            if ( idParamFileStr == i[1].get('name') ):
                paramIdValue = i[1].get('id')
                paramIdFound = True
                syslog.syslog(LOG_LVL, 'parameter id for \'{0}\' (file: {1}) found, value is: {2}'.format(idParamFileStr, xmlValueFileName, paramIdValue))
                break

if ( False == paramIdFound ):
    syslog.syslog(syslog.LOG_ERR, 'could not get parameter id for \'{0}\' (file: {1})'.format(idParamFileStr, xmlValueFileName))
    sys.exit(4)

if ( paramIdValue is None):
    syslog.syslog(syslog.LOG_ERR, 'parameter id for \'{0}\' (file: {1}) is None'.format(idParamFileStr, xmlValueFileName))
    sys.exit(5)


#
# Write id to stdout and exit
#
sys.stdout.write('{0}'.format(paramIdValue))
sys.exit(0)

