#!/bin/sh

# exit codes
EXIT_OK=0
EXIT_ERR_NOTHING_TO_REINIT=1     # No error occurred but no IDs send by parameter changed message
EXIT_ERR_FILE_NOT_EXIST=2        # a XML value or meta not exist
EXIT_ERR_RECREATION_FAILED=3     # could not re-create XML value file from meta file default values
EXIT_ERR_UNKNOWN_PARAMFILE_ID=4  # could not get the XML parameter file id from Python class
EXIT_ERR_OTHER_ERR=5             # other error occured

# directories
PATH_TO_VALUE_FILES="/var/Counter/config"
PATH_TO_META_FILES="/etc/Counter/ParamMetaFiles"

# tools
PROG_CHECK_XML_FILE="/sbin/CheckXmlParamFile"
PROG_GET_PARAM_ID="/usr/local/bin/python3 /usr/local/bin/d_get_paramfileid.py"
PROG_SEND_MSG="/usr/local/bin/APC_SendMsg"

# Msg related IDs for parameter changed message
APP_ID_PARAM_HANDLING=16
PH_MSG_ID_PARAM_FILES_CHANGED=1

# verbose syslog (set to "notice" for verbose output)
LOG_LVL_VERBOSE="info"


########################################################################


# Get command line arguments (file name list)
# Note: no spaces allowed in file name arguments
FILE_LIST=$@


# Get own PID
OWN_PID=$$


# loop all file name arguments
CNT_IDS=0
ID_LIST=""
for f in $FILE_LIST ; do
    logger -p user.$LOG_LVL_VERBOSE "$0: arg (file): $f"
    
    #
    # Get meta file from value file name, set up FQFN for value and meta files
    #
    META_FILE_NAME=`echo "$f" | sed -e "s/_values.xml/_meta.xml/g"`
    META_FILE_FQFN="$PATH_TO_META_FILES/$META_FILE_NAME"
    VALUE_FILE_FQFN="$PATH_TO_VALUE_FILES/$f"
    logger -p user.$LOG_LVL_VERBOSE "$0: VALUE_FILE_FQFN: $VALUE_FILE_FQFN"
    logger -p user.$LOG_LVL_VERBOSE "$0: META_FILE_FQFN : $META_FILE_FQFN"
    
    
    #
    # both file must exist !
    #
    if [ ! -f $META_FILE_FQFN ] ; then
        logger -p user.error "$0: XML meta file not exist: $META_FILE_FQFN"
        exit $EXIT_ERR_FILE_NOT_EXIST
    fi
    if [ ! -f $VALUE_FILE_FQFN ] ; then
        logger -p user.error "$0: XML value file not exist: $VALUE_FILE_FQFN"
        exit $EXIT_ERR_FILE_NOT_EXIST
    fi
    
    
    #
    # Validate parameter file (validation only)
    #
    $PROG_CHECK_XML_FILE -o -m $META_FILE_FQFN -v $VALUE_FILE_FQFN >/dev/null 2>&1
    CHECK_RES=$?
    case $CHECK_RES in
        0)
            # validation successfull, nothing to do here
            logger -p user.$LOG_LVL_VERBOSE "$0: validation successful for: $VALUE_FILE_FQFN"
            ;;
        1)
            logger -p user.error "$0: ${PROG_CHECK_XML_FILE} result: invalid arguments"
            exit $EXIT_ERR_OTHER_ERR
            ;;
        2)
            logger -p user.error "$0: Validation failed for: $VALUE_FILE_FQFN"
            logger -p user.notice "$0: Try to restore default values from meta file for: $VALUE_FILE_FQFN"
            $PROG_CHECK_XML_FILE -m $META_FILE_FQFN -v $VALUE_FILE_FQFN >/dev/null 2>&1
            CHECK_RES_2=$?
            if [ $CHECK_RES_2 -ne 0 ] ; then
                logger -p user.error "$0: Could not restore from default values (err code: ${CHECK_RES_2}): $VALUE_FILE_FQFN"
                exit $EXIT_ERR_RECREATION_FAILED
            fi
            ;;
        3)
            logger -p user.error "$0: ${PROG_CHECK_XML_FILE} result: creation error"
            exit $EXIT_ERR_OTHER_ERR
            ;;
        *)
            logger -p user.error "$0: ${PROG_CHECK_XML_FILE} result: unknown return value"
            exit $EXIT_ERR_OTHER_ERR
            ;;
    esac
    
    
    #
    # Get ID for parameter changed message
    #
    ID=`$PROG_GET_PARAM_ID $f`
    RET=$?
    if [ $RET -ne 0 ] ; then
        # exit with an error code
        logger -p user.error "$0: $PROG_GET_PARAM_ID returned an error (err code: $RET) for: $VALUE_FILE_FQFN"
        exit $EXIT_ERR_UNKNOWN_PARAMFILE_ID
    fi
    logger -p user.$LOG_LVL_VERBOSE "$0: Extracted parameter file (for \'${f}\') ID: $ID"
    
    
    # If ID equals 0 add it to list and increment cnt variable
    if [ $ID -ne 0 ] ; then
        # Increment number of IDs
        CNT_IDS=`expr $CNT_IDS + 1`
        # Add ID to ID list
        ID_LIST="$ID_LIST $ID"
    fi
done


logger -p user.$LOG_LVL_VERBOSE "$0: CNT_IDS: $CNT_IDS"
logger -p user.$LOG_LVL_VERBOSE "$0: ID_LIST: $ID_LIST"


# Send parameter changed message
if [ $CNT_IDS -ge 1 ] ; then
    MSG_ARGS="$APP_ID_PARAM_HANDLING $PH_MSG_ID_PARAM_FILES_CHANGED $OWN_PID $CNT_IDS $ID_LIST"
    logger -p user.$LOG_LVL_VERBOSE "$0: MSG_ARGS: $MSG_ARGS"
    $PROG_SEND_MSG $MSG_ARGS
    exit $EXIT_OK
else
    exit $EXIT_ERR_NOTHING_TO_REINIT
fi

