class COrientation:
    Model_Unknown = 0
    Model_EH      = 1
    Model_GH      = 2
    Model_HH      = 3
    Model_IH      = 4
    Model_JH      = 5
    def __init__(self):
        self.ModelStr = COrientation.RetrieveModelStr()
        self.Model    = COrientation.ModelStr2Model(self.ModelStr)


    @staticmethod
    def ModelStr2Model(ModelStr):
        if not ModelStr:
            return COrientation.Model_Unknown

        if ModelStr.startswith("EH"):
            return COrientation.Model_EH
        elif ModelStr.startswith("GH"):
            return COrientation.Model_GH
        elif ModelStr.startswith("HH"):
            return COrientation.Model_HH
        elif ModelStr.startswith("IH"):
            return COrientation.Model_IH
        elif ModelStr.startswith("JH"):
            return COrientation.Model_JH
        return COrientation.Model_Unknown


    @staticmethod
    def RetrieveModelStr():
        Filename = "/hwconfig/hwconfig.txt"
        ret = None
        with open(Filename, "r") as f:
            for line in f:
                if line.startswith("Model="):
                    ret = line.split("=")[1].strip()
                    break
        return ret


    def isModelIdentified(self):
        return self.Model != COrientation.Model_Unknown


    def xyz2vlt(self, x_mg, y_mg, z_mg):
        if self.Model in (COrientation.Model_EH, COrientation.Model_GH):
            return z_mg, x_mg, y_mg
        elif self.Model in (COrientation.Model_HH, COrientation.Model_IH, COrientation.Model_JH):
            return z_mg, y_mg, x_mg

        # default for unknown type (or shall we return None for the sake of
        # clearness):
        return x_mg, y_mg, z_mg

    def vlt2xyz(self, v_mg, l_mg, t_mg):
        if self.Model in (COrientation.Model_EH, COrientation.Model_GH):
            return l_mg, t_mg, v_mg
        elif self.Model in (COrientation.Model_HH, COrientation.Model_IH, COrientation.Model_JH):
            return t_mg, l_mg, v_mg

        # default for unknown type (or shall we return None for the sake of
        # clearness):
        return v_mg, l_mg, t_mg
#--------------------------------------------------------------------------------------------------
class CAccelDataReader:
    def __init__(self):
        sysdir = '/sys/devices/soc0/amba/e0005000.i2c/i2c-1/1-0018/iio:device1/'
        self._XFilename = sysdir + "in_accel_x_raw"
        self._YFilename = sysdir + "in_accel_y_raw"
        self._ZFilename = sysdir + "in_accel_z_raw"
        self._SamplingFrequencyFilename = sysdir + "sampling_frequency"
        self._fps = [None] * 3
        if self._SetSamplingRate():
            self._OpenSysfiles()


    def __del__(self):
        for i in range(3):
            if self._fps[i]:
                self._fps[i].close()
                self._fps[i] = None


    def _SetSamplingRate(self):
        Success = True
        try:
            sf_fp = open(self._SamplingFrequencyFilename, "w")
            sf_fp.write("200")
        except IOError:
            Success = False
        sf_fp.close()
        return Success


    def _OpenSysfiles(self):
        try:
            self._fps[0] = open(self._XFilename, "r")
            self._fps[1] = open(self._YFilename, "r")
            self._fps[2] = open(self._ZFilename, "r")
        except IOError:
            return False
        return True

    def GetAccelValues_mg(self):
        """Delivers the accel values in mg."""
        ret = [None] * 3
        try:
            for i in range(3):
                self._fps[i].seek(0)
                ret[i] = int(self._fps[i].readline())
        except (IOError, ValueError):
            pass
        return ret
