import sys, os
import signal
import libUserWatchdogCommExt
import time

class CWatchdogHandler():
    def __init__(self):
        # register watchdog
        libUserWatchdogCommExt.UW_Register(0)
        self.lastTriggerTime = time.monotonic()

    def __del__(self):
        libUserWatchdogCommExt.UW_Unregister()

    def checkTrigger(self, timeoutMS=1000.):
        currTime = time.monotonic()
        timeDiff = currTime - self.lastTriggerTime
        if timeDiff > (timeoutMS/1000.):
            libUserWatchdogCommExt.UW_Trigger()
            self.lastTriggerTime = currTime

# custom exception class for term signal
class CTermSignalException(Exception):
    pass

class CTermSignalHandler:
    def __init__(self):
        self.SignalReceived = False
        signal.signal(signal.SIGINT , self.HandleSignal)    # No.  2, Ctrl-C
        signal.signal(signal.SIGTERM, self.HandleSignal)    # No. 15, default kill signal
    def HandleSignal(self, signum, frame):
        self.SignalReceived = True
        # select.poll will not be interrupted (opposing to C) on signal
        # reception. So we additionally raise an interrupt for poll() waking up.
        raise CTermSignalException()


def daemonize():
    try:
        pid = os.fork()
        if pid > 0:
            sys.exit(0)     # Exit parent
    except OSError:
        # TODO: log the failure
        sys.exit(1)

    os.chdir("/")
    os.setsid() # We are now session leader and might open controlling console
    os.umask(0)

    try:
        # After this second fork we are no longer session leader and hence cannot
        # open /dev/console any longer.
        pid = os.fork()
        if pid > 0:
            sys.exit(0)     # Exit parent
    except OSError:
        # TODO: log failure
        sys.exit(1)


    if hasattr(os, "devnull"):
        devnull = os.devnull
    else:
        devnull = "/dev/null"
    os.open(devnull, os.O_RDWR)

    sys.stdout.flush()
    sys.stderr.flush()

    si = open(devnull, "rb")
    so = open(devnull, "a+b")
    se = open(devnull, "a+b")

    os.dup2(si.fileno(), sys.stdin.fileno())    # == 0
    os.dup2(so.fileno(), sys.stdout.fileno())   # == 1
    os.dup2(se.fileno(), sys.stderr.fileno())   # == 2

    si.close()
    so.close()
    se.close()
