'''
Created on Mar 6, 2015

@author: mas
'''

import logging
import imgProcExt as ip
from subprocess import Popen, PIPE
from copy import deepcopy

logger = logging.getLogger("PeopleCounter.CountingAoi")

# copied from System/commands.py (not accessable from site-package folder)
def getCommandOutput2(command):
    proc = Popen(command, stdout=PIPE, stderr=PIPE, shell=True)
    out, err = proc.communicate()
    exitcode = proc.returncode

    # stdout and stderr
    msgOut = "{0}".format(out.decode('utf-8')) if (len(out) > 0) else ""
    msgErr = "{0}".format(err.decode('utf-8')) if (len(err) > 0) else ""

    d = { "exitcode" : exitcode, "stdout" : msgOut, "stderr" : msgErr }

    return d

def getHeightOfPoint(pnt):
    # Build and execute command
    cmd  = '/usr/local/bin/FloorComp_GetHeightOfPoint'
    cmd += ' '
    cmd += str(pnt[0])
    cmd += ' '
    cmd += str(pnt[1])
    cmd += ' '
    cmd += '/tmp/avgdispimg.pgm'
    data = getCommandOutput2(cmd)

    if data['exitcode'] == 0:
        return int(data['stdout'])
    else:
        return 0

def updateAoi(elevMapAoiParams, floorCompParams):

    # create a new floor comp params structure with aoi (polygon) points and all
    # user defined points which lie inside of polygon

    fcpNew = {  'Count':{'value':0},
                'FcPointList':[]
    }
    # add all aoi points
    aoiCnt = elevMapAoiParams['Count']['value']
    fcpCnt = floorCompParams['Count']['value']
    poly = [] # used later for polygon inside test
    for i in range(aoiCnt):
        pnt = elevMapAoiParams['PointList'][i]
        pntX = pnt['X']['value']
        pntY = pnt['Y']['value']

        poly.append(pntX)
        poly.append(pntY)

        # search for point in floorCompParams
        isFound = False
        for j in range(fcpCnt):
            fPnt = floorCompParams['FcPointList'][j]
            fPntX = fPnt['Point']['X']['value']
            fPntY = fPnt['Point']['Y']['value']
#            logger.info("j = {}".format(j))
            if ((fPntX==pntX) and (fPntY==pntY)):
                # logger.info("i = {}, lenght: {}".format(i, len(fcpNew['FcPointList'])))
                fcpNew['FcPointList'].append(deepcopy(fPnt))
                isFound = True
                break

        if not isFound:
            measuredHeight = getHeightOfPoint([pntX, pntY])
            newPoint = {'Point':{'X':{'value':pntX},
                                 'Y':{'value':pntY}},
                        'IsSupportPoint':{'value':1},
                        'Height':{'value':measuredHeight},
                        'HeightMeasured':{'value':measuredHeight}}
            fcpNew['FcPointList'].append(deepcopy(newPoint))

    fcpnCnt = aoiCnt

    # add all user points which lie inside of aoi
    # for the inside-test we will use a C-Ext Library which will accept a
    # simpler data structure

    # add points which aren't support points and lie inside of polygon
    for i in range(fcpCnt):
        point = floorCompParams['FcPointList'][i]
        isSupportPoint = point['IsSupportPoint']['value']
        if isSupportPoint:
            continue
        xCoord = point['Point']['X']['value']
        yCoord = point['Point']['Y']['value']
        pnt = (xCoord, yCoord)
        isInside = ip.isInPolygon(poly, pnt)
        if isInside == None:
#            return None;
            continue

        if isInside==1:
            # add point
            fcpNew['FcPointList'].append(deepcopy(point))
            fcpnCnt = fcpnCnt+1

    fcpNew['Count']['value'] = fcpnCnt

    return fcpNew


