'''
Created on Mar 6, 2015

@author: mas
'''

import imgProcExt as ip


class PyTransformator():
    """ height, pitch, yaw: floats unscaled in mm and degrees
        focalLength  [1/256px], baseDistance [1/256mm], principalPoint [1/16px] as integers
    """
    def __init__(self, intParams, extParams):
        self.height = extParams['Height']['value']
        self.pitch  = extParams['AnglePitch']['value']
        self.yaw    = extParams['AngleYaw']['value']

        self.intExtTrafo = ip.createTrafoParams(intParams['pxFocalLength']['value'],
                                                intParams['mmBaseDistanceX']['value'],
                                                intParams['pxRightPrincipalPointX']['value'],
                                                intParams['pxRightPrincipalPointY']['value'],
                                                extParams['Height']['value'],
                                                extParams['AnglePitch']['value'],
                                                extParams['AngleYaw']['value'])

    def world2img(self, worldPnt):
        """ worldpoint must be in scaled integers (1/16mm)
            return type is scaled image coordinates (1/16px)
        """
        return ip.world2img(worldPnt, self.intExtTrafo)

    def world2cam(self, worldPnt):
        """ worldpoint must be in scaled integers (1/16mm)
            return type is scaled cam coordinates (1/16px)
        """
        return ip.world2cam(worldPnt, self.intExtTrafo)

    def img2groundplane(self, imgPnt, height):
        """ image point must be in scaled integers (1/16px)
            return type are scaled integers (1/16mm)
        """
        return ip.img2groundplane(imgPnt, height, self.intExtTrafo)

    def getInternal(self):
        return self.intExtTrafo[0]

    def getExternal(self):
        return self.intExtTrafo[1]

    def getExternalRotation(self):
        return self.getExternal()[0]

    def getExternalTranslation(self):
        return self.getExternal()[1]

    def setExternalTranslation(self, trans):
        newTrafo = (self.getInternal(), (self.getExternalRotation(), trans))
        self.intExtTrafo = newTrafo

    def getInternalFocalLength(self):
        return self.getInternal()[0]

    def getInternalBaseDistance(self):
        return self.getInternal()[1]

    def getInternalPrincipalPointX(self):
        return self.getInternal()[2]

    def getInternalPrincipalPointY(self):
        return self.getInternal()[3]

def calcMapRect(height, transformator, mapSize):
    return ip.calcMapRect(height, transformator.intExtTrafo, mapSize)

