#!/bin/sh

# Debug output
# set -x

# Return with error on uninitialized variables
set -u

# Return immediately on error of a command (esp. of the grep commands at the end of the for loop)
# set -e

# Actual data without regular expressions
F1=$1
# Ground truth data with regular expressions
F2=$2

# Get the number of lines
S1=$(wc -l $F1 | cut -d' ' -f1)
S2=$(wc -l $F2 | cut -d' ' -f1)

# Compare thge number of lines
if [ $S1 -ne $S2 ] ; then
    echo "$0: line count mismatch"
    exit 1
fi


for I in $(seq 1 $S1) ; do 
    # Get the I-th line of each file
    L1=$(tail -n+$I $F1 | head -n1)
    L2=$(tail -n+$I $F2 | head -n1)
    
    # Compare actual data with ground truth data including regular expessions
    echo $L1 | grep -e "$L2" > /dev/null
    if [ $? -ne 0 ] ; then 
        echo "$0: line $I mismatch"
        exit 2
    fi
done

# OK
echo "$0: no differences"
exit 0
